# earthkit-data-demo-source


**DISCLAIMER**

> This project is just a demo and **not supported** for operational use at all. **DO NOT USE** it in operations.


This is an example of a **data sources plugin** for [earthkit-data](https://earthkit-data.readthedocs.io/). It enables earthkit-data to access data from an SQL database. 

## Install

```pip install earthkit-data-demo-source```

## Usage

See https://earthkit-data.readthedocs.io/en/feature-plugins/plugins/sources_plugin.html  


## License

```
Copyright 2023, European Centre for Medium Range Weather Forecasts.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

In applying this licence, ECMWF does not waive the privileges and immunities
granted to it by virtue of its status as an intergovernmental organisation
nor does it submit to any jurisdiction.
```